﻿using System;
using Foundation;
using Syncfusion.SfChart.iOS;
using UIKit;

namespace Chart_GettingStarted
{
	public partial class ViewController : UIViewController
	{
		protected ViewController(IntPtr handle) : base(handle)
		{
			// Note: this .ctor should not contain any initialization logic.
		}

		public override void DidReceiveMemoryWarning()
		{
			base.DidReceiveMemoryWarning();
			// Release any cached data, images, etc that aren't in use.
		}

		SFChart chart;
		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			chart = new SFChart();
			chart.Frame = this.View.Frame;

			//Adding Primary Axis for the Chart.
			SFDateTimeAxis primaryAxis = new SFDateTimeAxis();
			NSDateFormatter dateFormatter = new NSDateFormatter();
			dateFormatter.DateFormat = "dd/MM/yyyy HH:mm:ss";
			primaryAxis.LabelStyle.LabelFormatter = dateFormatter;
			chart.PrimaryAxis = primaryAxis;

			//Adding Secondary Axis for the Chart.
			SFNumericalAxis secondaryAxis = new SFNumericalAxis();
			secondaryAxis.Title.Text = new NSString("Temperature");
			chart.SecondaryAxis = secondaryAxis;

			//Defining the data source for the Chart.
			ChartDataModel dataModel = new ChartDataModel();
			chart.DataSource = dataModel as SFChartDataSource;

			chart.Delegate = new ChartDelegate();

			chart.AddChartBehavior(new SFChartZoomPanBehavior());

			//Adding our Chart as a sub view.
			this.View.AddSubview(chart);
		}

		public override void ViewDidLayoutSubviews()
		{
			chart.Frame = this.View.Frame;
			base.ViewDidLayoutSubviews();
		}

	}

	public class ChartDelegate : SFChartDelegate
	{

		DateTime dateTime;

		public override NSString GetFormattedAxisLabel(SFChart chart, NSString label, NSObject value, SFAxis axis)
		{
			if (axis is SFDateTimeAxis)
			{
				dateTime = DateTime.ParseExact(label, "dd/MM/yyyy HH:mm:ss", System.Globalization.CultureInfo.CurrentCulture);

				if ((axis as SFDateTimeAxis).ActualIntervalType == SFChartDateTimeIntervalType.Hours || (axis as SFDateTimeAxis).ActualIntervalType == SFChartDateTimeIntervalType.Minutes ||
					(axis as SFDateTimeAxis).ActualIntervalType == SFChartDateTimeIntervalType.Seconds || (axis as SFDateTimeAxis).ActualIntervalType == SFChartDateTimeIntervalType.Milliseconds)

				{
					if (dateTime.Hour == 0 && dateTime.Minute == 0 && dateTime.Second == 0 && dateTime.Millisecond == 0)
					{
						label = new NSString(GetMonth(dateTime.Month) + " " + dateTime.Day);
					}

					else
					{
						if (dateTime.Minute > 9)
						{
							label = new NSString(dateTime.Hour + ":" + dateTime.Minute);
						}
						else
						{
							label = new NSString(dateTime.Hour + ":0" + dateTime.Minute);
						}
					}
				}
			}
			else {
				if (axis is SFDateTimeAxis)
				{
					label = (Foundation.NSString)(dateTime.Day + "/n" + (GetMonth(dateTime.Month) + " " + dateTime.Year));
				}
			}

			return label;
		}

		string GetMonth(int val)
		{
			switch (val)
			{
				case 1: return "Jan";
				case 2: return "Feb";
				case 3: return "Mar";
				case 4: return "Apr";
				case 5: return "May";
				case 6: return "Jun";
				case 7: return "Jul";
				case 8: return "Aug";
				case 9: return "Sep";
				case 10: return "Oct";
				case 11: return "Nov";
				case 12: return "Dec";
			}

			return null;
		}


	}
	public class ChartDataModel : SFChartDataSource
	{
		NSMutableArray DataPoints;

		public ChartDataModel()
		{
			DataPoints = new NSMutableArray();

			DateTime date = new DateTime(2017, 1, 1);

			AddDataPointsForChart(date.AddDays(1), 10);
			AddDataPointsForChart(date.AddDays(2), 30);
			AddDataPointsForChart(date.AddDays(3), 15);
			AddDataPointsForChart(date.AddDays(4), 65);
			AddDataPointsForChart(date.AddDays(5), 90);

		}

		void AddDataPointsForChart(DateTime XValue, Double YValue)
		{
			NSCalendar cal = new NSCalendar(NSCalendarType.Gregorian);
			NSDateComponents comp = new NSDateComponents();
			comp.Day = XValue.Day;
			comp.Month = XValue.Month;
			comp.Year = XValue.Year;
			comp.Hour = XValue.Hour;
			comp.Minute = XValue.Minute;
			comp.Second = XValue.Second;
			DataPoints.Add(new SFChartDataPoint(cal.DateFromComponents(comp), NSObject.FromObject(YValue)));
		}

		public override nint NumberOfSeriesInChart(SFChart chart)
		{
			return 1;
		}

		public override SFSeries GetSeries(SFChart chart, nint index)
		{
			SFLineSeries series = new SFLineSeries();
			series.DataMarker.ShowLabel = true;
			return series;
		}

		public override SFChartDataPoint GetDataPoint(SFChart chart, nint index, nint seriesIndex)
		{
			return DataPoints.GetItem<SFChartDataPoint>((nuint)index);
		}

		[Export("chart:numberOfDataPointsForSeriesAtIndex:")]
		public override nint GetNumberOfDataPoints(SFChart chart, nint index)
		{
			return (int)DataPoints.Count;

		}
	}
}

